<?xml version="1.0" encoding="ISO-8859-1"?>

<!--  Copyright 2010,2015 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 24/11/2016
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-dev@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:dc="http://purl.org/dc/elements/1.1/" 
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
                xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
                xmlns:owl ="http://www.w3.org/2002/07/owl#"
                xmlns:skos="http://www.w3.org/2004/02/skos/core#"
                xmlns:dct="http://purl.org/dc/terms/"
                xmlns:foaf="http://xmlns.com/foaf/0.1/"
                xmlns:dcat="http://www.w3.org/ns/dcat#"
                xmlns:adms="http://www.w3.org/ns/adms#"
                xmlns:vcard="http://www.w3.org/2006/vcard/ns#"
                xmlns:voaf="http://labs.mondeca.com/vocab/voaf#"
                xmlns:vann="http://purl.org/vocab/vann/"
> 
    
    <!--Output settings-->
    <xsl:output method="xml" media-type="application/x-ror-rdf+xml" version="1.0" encoding="UTF-8" indent="yes"/>
    
    <!-- Includes -->
    <xsl:include href="config.xsl" />
    
    <xsl:template match="/">
        <rdf:RDF>
            <xsl:apply-templates select="register"/>
        </rdf:RDF>
    </xsl:template>
    
    <xsl:template match="register">
        <rdf:Description rdf:about="{uri}">
            <rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#ConceptScheme"/>
        
            <dct:isPartOf>
                <dcat:Catalog rdf:about="{registry}"/>
            </dct:isPartOf>
            
            <xsl:variable name="uriItem" select="uri" /> 
            
            <xsl:for-each select="$sharedRegisters">	
                <xsl:if test="@id=$uriItem">
                    <xsl:if test="@reliesOn">
                        <voaf:reliesOn rdf:resource="{@reliesOn}"/> 
                    </xsl:if>
                </xsl:if>
            </xsl:for-each>
            
            <xsl:if test="label != ''">
                <skos:prefLabel xml:lang="{label/@language}">
                    <xsl:value-of select="label" />
                </skos:prefLabel>
            </xsl:if>
            
            <xsl:if test="definition != ''">
                <skos:definition xml:lang="{definition/@language}">
                    <xsl:value-of select="definition" />
                </skos:definition>
            </xsl:if>
            
            <dct:accrualPeriodicity rdf:resource="{$updateFrequency}"/>
            
            <dct:publisher>
                <foaf:Agent rdf:about="{$publisherID}">
                    <foaf:name xml:lang="en">
                        <xsl:value-of select="$publisherName" />
                    </foaf:name>
                    <foaf:mbox rdf:resource="mailto:{$publisherEmail}"/>
                    <foaf:homepage rdf:resource="{$publisherHomepage}"/>
                </foaf:Agent>
            </dct:publisher>
            
        </rdf:Description>
          
            
        <xsl:choose>
            <xsl:when test="items">
                <!--<dcat:dataset>-->
                <xsl:for-each select="items/item">
                        
                    <rdf:Description rdf:about="{uri}">
                        <xsl:if test="uriname != ''">
                            <rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
                        </xsl:if>
                        
                        <skos:inScheme rdf:resource="{register}"/>
                            
                        <xsl:if test="uriname != ''">
                            <xsl:variable name="itemLabel" select="label" />
                            <xsl:if test="$itemLabel != ''">
                                <skos:prefLabel xml:lang="{$itemLabel/@language}">
                                    <xsl:value-of select="$itemLabel" />
                                </skos:prefLabel>
                            </xsl:if>
            
                            <xsl:variable name="itemDefinition" select="definition" />
                            <xsl:if test="$itemDefinition != ''">
                                <skos:definition xml:lang="{$itemDefinition/@language}">
                                    <xsl:value-of select="$itemDefinition" />
                                </skos:definition>
                            </xsl:if>
                            <adms:status rdf:resource="{status}"/>
                        </xsl:if>
                    </rdf:Description>
                         
                </xsl:for-each>
                <!--</dcat:dataset>-->  
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
        
        <xsl:choose>
            <xsl:when test="collection">
                <!--<dcat:dataset>-->
                
                <xsl:for-each select="collection/item">
                
                    <xsl:variable name="item_uri">
                        <xsl:choose>
                            <xsl:when test="uriname">
                                <xsl:value-of select="uri"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="uristandard"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:variable>
                        
                    <rdf:Description rdf:about="$item_uri">
                        <xsl:if test="uriname != ''">
                            <rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
                        </xsl:if>
                        
                        <xsl:if test="register != ''">
                            <skos:inScheme rdf:resource="{register}"/>
                        </xsl:if>
                            
                        <xsl:if test="label != ''">
                            <xsl:variable name="itemLabel" select="label" />
                            <xsl:if test="$itemLabel != ''">
                                <skos:prefLabel xml:lang="{$itemLabel/@language}">
                                    <xsl:value-of select="$itemLabel" />
                                </skos:prefLabel>
                            </xsl:if>
                        </xsl:if>
            
                        <xsl:if test="definition != ''">
                            <xsl:variable name="itemDefinition" select="definition" />
                            <skos:description xml:lang="{$itemDefinition/@language}">
                                <xsl:value-of select="$itemDefinition" />
                            </skos:description>
                        </xsl:if>
                        
                        <xsl:if test="status != ''">
                            <adms:status rdf:resource="{status}"/>
                        </xsl:if>
                    </rdf:Description>
                         
                </xsl:for-each>
                <!--</dcat:dataset>-->  
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
            
    </xsl:template>
</xsl:stylesheet>