<?xml version="1.0" encoding="ISO-8859-1"?>

<!--  Copyright 2010,2015 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 24/11/2016
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-dev@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" 
               xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
               xmlns:dc="http://purl.org/dc/elements/1.1/" 
               xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
               xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
               xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
               xmlns:owl ="http://www.w3.org/2002/07/owl#"
               xmlns:skos="http://www.w3.org/2004/02/skos/core#"
               xmlns:dct="http://purl.org/dc/terms/"
               xmlns:foaf="http://xmlns.com/foaf/0.1/"
               xmlns:dcat="http://www.w3.org/ns/dcat#"
               xmlns:adms="http://www.w3.org/ns/adms#"
               xmlns:vcard="http://www.w3.org/2006/vcard/ns#"
               xmlns:vann="http://purl.org/vocab/vann/"
> 
    
    <!--Output settings-->
    <xsl:output method="xml" media-type="application/x-ror-rdf+xml" version="1.0" encoding="UTF-8" indent="yes"/>
    
    <!-- Includes -->
    <xsl:include href="config.xsl" />
    
    <xsl:template match="/">
        <rdf:RDF>
            <xsl:apply-templates select="registry"/>
        </rdf:RDF>
    </xsl:template>
    
    <xsl:template match="registry">
        <rdf:Description rdf:about="{uri}">
            <rdf:type rdf:resource="http://www.w3.org/ns/dcat#Catalog"/>
        
            <xsl:if test="label != ''">
                <dct:title xml:lang="{label/@language}">
                    <xsl:value-of select="label" />
                </dct:title>
            </xsl:if>
            
            <xsl:if test="definition != ''">
                <dct:description xml:lang="{definition/@language}">
                    <xsl:value-of select="definition" />
                </dct:description>
            </xsl:if>
            
            <dct:publisher>
                <foaf:Agent rdf:about="{$publisherID}">
                    <foaf:name xml:lang="en">
                        <xsl:value-of select="$publisherName" />
                    </foaf:name>
                    <foaf:mbox rdf:resource="mailto:{$publisherEmail}"/>
                    <foaf:homepage rdf:resource="{$publisherHomepage}"/>
                </foaf:Agent>
            </dct:publisher>
            
            <dct:accrualPeriodicity rdf:resource="{$updateFrequency}"/>
          
            
            <xsl:choose>
                <xsl:when test="registers">
                    <xsl:for-each select="registers/register">
                        <dcat:dataset>	
                            <xsl:variable name="uriItem" select="uri" />
                            <rdf:Description rdf:about="{$uriItem}">
                                <dcat:distribution rdf:parseType="Resource">
                                    <dct:format rdf:resource="http://publications.europa.eu/resource/authority/file-type/RDF_XML"/>

                                    <xsl:variable name="uri_descriptor" select="uri_descriptor" />
                                    
                                    
                                    <xsl:variable name="descriptorLocationFromConfig"> 
                                        <xsl:for-each select="$sharedRegisters">	
                                            <xsl:choose>
                                                <xsl:when test="(@id=$uriItem) and (@descriptorLocation)">
                                                    <xsl:value-of select="@descriptorLocation"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:for-each>
                                       
                                    </xsl:variable>

                                    <xsl:choose>
                                        <xsl:when test="$descriptorLocationFromConfig=''">
                                            <dcat:downloadURL rdf:resource="{$uri_descriptor}"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <dcat:downloadURL rdf:resource="{$descriptorLocationFromConfig}"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    
                                </dcat:distribution>
                            </rdf:Description>
                        </dcat:dataset>
                        
                         
                    </xsl:for-each>
                </xsl:when>
                <xsl:otherwise>
                </xsl:otherwise>
            </xsl:choose>
            
        </rdf:Description>
    </xsl:template>
</xsl:stylesheet>