/*
 * Copyright 2010,2015 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 24/11/2016
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistry.module;

import eu.europa.ec.re3gistry.constants.Constants;
import eu.europa.ec.re3gistry.utils.locale.LocalizationMgr;
import java.io.File;
import java.io.FilenameFilter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import org.apache.log4j.Logger;

public class ModuleMgr {

    private static ArrayList<Module> modules;
    private static final Logger log = Logger.getLogger(ModuleMgr.class);

    /**
     * Returns the ArrayList containing all the modules loaded.
     *
     * @param servletContext the ServletContext
     * @param request
     * @return the ArrayList containing all the modules loaded.
     */
    public static ArrayList<Module> getModules(ServletContext servletContext, HttpServletRequest request) {
        if (modules == null) {
            modules = loadModules(servletContext, request);
        }
        return modules;
    }

    /**
     * This method load all the modules in the static variable modules. Returns
     * the ArrayList containing all the modules loaded.
     *
     * @param servletContext the ServletContext
     * @return the ArrayList containing all the modules loaded.
     */
    private static ArrayList<Module> loadModules(ServletContext servletContext, HttpServletRequest request) {
        modules = new ArrayList<>();

        //Getting the path from servlet context
        String modulePath = servletContext.getRealPath("/" + Constants.MODULE_PATH);
        File f = new File(modulePath);

        //Listing all the directories; each directory is a module. The name of 
        //the module is the name of the directory.
        String[] moduleDirectory = f.list(new FilenameFilter() {
            @Override
            public boolean accept(File current, String name) {
                return new File(current, name).isDirectory();
            }
        });

        if (moduleDirectory == null || moduleDirectory.length <= 0) {
            //log.info("No modules were found.");
            return modules;
        }

        //Initializing the modules
        for (String moduleName : moduleDirectory) {
            Module m = new Module(moduleName, LocalizationMgr.getCurrentLocale(request));
            //Storing the module in the arraylist if it is active (information 
            //from the module's property file)
            if (m.isModuleActive()) {
                modules.add(m);
            }
        }

        Collections.sort(modules, new Comparator<Module>() {
            @Override
            public int compare(Module m1, Module m2) {
                return m1.getMenuOrder() - m2.getMenuOrder();
            }
        });

        return modules;
    }
}
