/*
 * Copyright 2010,2015 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 24/11/2016
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrycommon.model;

import eu.europa.ec.re3gistrycommon.utils.StringUtils;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlRootElement;

@Entity
@Table(name = "changelog")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Changelog.findAll", query = "SELECT c FROM Changelog c"),
    @NamedQuery(name = "Changelog.findByUuid", query = "SELECT c FROM Changelog c WHERE c.uuid = :uuid"),
    @NamedQuery(name = "Changelog.findByComment", query = "SELECT c FROM Changelog c WHERE c.comment = :comment"),
    @NamedQuery(name = "Changelog.findByAction", query = "SELECT c FROM Changelog c WHERE c.action = :action"),
    @NamedQuery(name = "Changelog.findByDatecreation", query = "SELECT c FROM Changelog c WHERE c.datecreation = :datecreation"),
    @NamedQuery(name = "Changelog.findAfterDatecreation", query = "SELECT c FROM Changelog c WHERE c.datecreation >= :datecreation"),
    @NamedQuery(name = "Changelog.findByDatelastupdate", query = "SELECT c FROM Changelog c WHERE c.datelastupdate = :datelastupdate"),
    /**
     * custom query
     */
    @NamedQuery(name = "Changelog.findByDataprocedure", query = "SELECT c FROM Changelog c WHERE c.dataprocedure = :dataprocedure")
})
public class Changelog implements Serializable {

    private static final long serialVersionUID = 1L;
    @Id
    @Basic(optional = false)
    @Column(name = "uuid")
    private String uuid;
    @Column(name = "comment")
    private String comment;
    @Basic(optional = false)
    @Column(name = "action")
    private String action;
    @Basic(optional = false)
    @Column(name = "datecreation")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datecreation;
    @Column(name = "datelastupdate")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datelastupdate;

    @JoinColumn(name = "item", referencedColumnName = "uuid")
    @ManyToOne(optional = false)
    private Item item;
    @JoinColumn(name = "dataprocedure", referencedColumnName = "uuid")
    @ManyToOne(optional = false)
    private Dataprocedure dataprocedure;

    public Changelog() {
    }

    public Changelog(String uuid) {
        this.uuid = uuid;
    }

    public Changelog(String uuid, String action, Date datecreationin) {
        this.uuid = uuid;
        this.action = action;
        this.datecreation = datecreationin;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public String getAction() {
        return action;
    }

    public void setAction(String action) {
        this.action = action;
    }

    public Date getDatecreation() {
        return this.datecreation;
    }

    public void setDatecreation(Date datecreationin) {
        this.datecreation = datecreationin;
    }

    public Date getDatelastupdate() {
        return this.datelastupdate;
    }

    public void setDatelastupdate(Date datelastupdatein) {
        this.datelastupdate = datelastupdatein;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (uuid != null ? uuid.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Changelog)) {
            return false;
        }
        Changelog other = (Changelog) object;
        return (this.uuid != null || other.uuid == null) && (this.uuid == null || this.uuid.equals(other.uuid));
    }

    @Override
    public String toString() {
        return "eu.europa.ec.re3gistrycommon.model.Changelog[ uuid=" + uuid + " ]";
    }

    /**
     * Creates the uuid for the Changelog's objects
     *
     * @param item
     * @param timestamp
     * @return the uuid
     * @throws Exception
     */
    public static String createUuid(Item item, long timestamp) throws Exception {
        //This is for uniqueness, because this uuid use the timestamp for the uuid creation
        Thread.sleep(10);
        return StringUtils.createUUID(item.getUuid() + Long.toString(timestamp), Changelog.class);
    }

    public Item getItem() {
        return item;
    }

    public void setItem(Item item) {
        this.item = item;
    }

    public Dataprocedure getDataprocedure() {
        return dataprocedure;
    }

    public void setDataprocedure(Dataprocedure dataprocedure) {
        this.dataprocedure = dataprocedure;
    }

}
