/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 30/03/2015
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.marshaller;

import eu.europa.ec.re3gistrycommon.managers.RegistryMgr;
import eu.europa.ec.re3gistrycommon.model.Registry;
import eu.europa.ec.re3gistrystaticizer.StaticizeFiles;
import eu.europa.ec.re3gistrystaticizer.util.Constants;
import java.io.File;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Properties;
import javax.persistence.EntityManager;
import javax.xml.transform.Transformer;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import net.sf.saxon.TransformerFactoryImpl;

public class CustomAdditionalFilesCreation {

    private String[] XSLEXTENSIONS;
    private final String folderSeparator = System.getProperty("file.separator");
    private static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);
    private final StaticizeFiles staticizeFiles;
    private final Properties properties;

    public CustomAdditionalFilesCreation(StaticizeFiles staticizeFiles, LinkedHashMap<File, String> linkedHashMapVAR, EntityManager em) throws Exception {
        this.staticizeFiles = staticizeFiles;

        properties = eu.europa.ec.re3gistrycommon.utils.Configuration.getInstance().getProperties(Constants.MODULE_NAME);
        initializateXSLCustomFiles();

        if (XSLEXTENSIONS.length != 0 && !XSLEXTENSIONS[0].equals("")) {
            createXSLCustomFiles(linkedHashMapVAR, em);
        }
    }

    private void initializateXSLCustomFiles() {
        String xslFormat = Constants.STATICIZER_XSL_FORMATS;
        String xslFormatSeparator = Constants.STATICIZER_FORMATS_ITEMS_SEPARATOR;

        String formatList = properties.getProperty(xslFormat);
        XSLEXTENSIONS = formatList.split(properties.getProperty(xslFormatSeparator));
    }

    private void createXSLCustomFiles(LinkedHashMap<File, String> linkedHashMapVAR, EntityManager em) throws Exception {
        List<File> folderItemList = new ArrayList<File>();

        String guilanguage = staticizeFiles.getStaticizerXSLFolder() + "/" + "gui-languages";
        String xslformatSeparatorSameCategory = properties.getProperty(Constants.STATICIZER_FORMATS_ITEMS_SAMECATEGORY_SEPARATOR);

        if (XSLEXTENSIONS.length != 0) {
            for (String customXSL : XSLEXTENSIONS) {

                String parentPath = null;
                if (customXSL.contains(xslformatSeparatorSameCategory)) {
                    String[] folderAndExtension = customXSL.split(xslformatSeparatorSameCategory);
                    parentPath = folderAndExtension[0];
                    customXSL = folderAndExtension[1];
                }

                String itemFileXSL = staticizeFiles.getStaticizerXSLFolder() + "/html/common/" + customXSL + ".xsl";
                String outputFolderPath;
                if (parentPath == null) {
                    outputFolderPath = staticizeFiles.getCreateStandardFiles().getFolderCustomStaticizer() + "/" + customXSL;
                } else {
                    File parentFolder = new File(staticizeFiles.getCreateStandardFiles().getFolderCustomStaticizer() + "/" + parentPath);
                    parentFolder.mkdir();
                    outputFolderPath = parentFolder + "/" + customXSL;
                }
                File outputFolder = new File(outputFolderPath);
                outputFolder.mkdir();

                transformCustom(new File(guilanguage), itemFileXSL, outputFolderPath, em);

                folderItemList.add(outputFolder);
            }

            for (File file : folderItemList) {
                if (!linkedHashMapVAR.containsKey(file)) {
                    linkedHashMapVAR.put(file, "");
                }
            }
        }
    }

    public void transformCustom(File fuilanguagesFolder, String xslFileUsedForTheTransformation, String outputFolder, EntityManager em) throws Exception {
        /**
         * Get all the file item in this folder
         */
        File[] fileList = fuilanguagesFolder.listFiles();
        /**
         * For each file item in this folder
         */
        for (File file : fileList) {
            /**
             * Check if the file item is a file
             */
            if (file.isFile()) {
                /**
                 * Get the filename and create the filename of the output file
                 */
                String filename = file.getAbsolutePath();
                String filenameTemp = file.getName();
                String newfilename = filenameTemp.replace(".xml", ".html");

                /**
                 * Creating folder for the custom format export
                 */
                File tmp = new File(xslFileUsedForTheTransformation);
                String resName = tmp.getName().substring(0, tmp.getName().lastIndexOf("."));

                String finalOutFile = outputFolder + folderSeparator + resName + "." + newfilename;

                /**
                 * If the file is an xml file, it has to be converted
                 */
                if (filename.endsWith(".xml")) {
                    /**
                     * Creating directories if needed
                     */
                    String newfolder = finalOutFile.substring(0, finalOutFile.lastIndexOf(folderSeparator));
                    if (!new File(newfolder).exists()) {
                        new File(newfolder).mkdirs();
                    }
                    /**
                     * Transform the file and write the new one
                     */
                    try {
                        TransformerFactoryImpl factory = new net.sf.saxon.TransformerFactoryImpl();
                        Transformer transformer = factory.newTransformer(new StreamSource(xslFileUsedForTheTransformation));

                        RegistryMgr registryMgr = new RegistryMgr(em);
                        Registry registry = registryMgr.findAll().get(0);

                        transformer.setParameter("baseuri", registry.getBaseuri());
                        transformer.setParameter("registryUriname", registry.getUriname());
                        log.info("Create with success: " + finalOutFile);
                        transformer.transform(new StreamSource(filename), new StreamResult(new File(finalOutFile)));
                    } catch (Exception ex) {
                        log.error(ex.getMessage());
                    }
                }
            }
        }
    }

    public String[] getXSLEXTENSIONS() {
        return XSLEXTENSIONS;
    }
}
