/*
 * Copyright 2010,2015 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 30/03/2015
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 * (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
 */
package eu.europa.ec.re3gistrystaticizer.vargenerator;

import eu.europa.ec.re3gistrystaticizer.util.Constants;
import java.io.File;
import java.util.HashMap;
import java.util.Properties;
import org.apache.commons.io.FileUtils;

public class VarGenerator {

    private static final long serialVersionUID = 1L;
    private static final String KEY_URI_PREFIX = "var.prefix.uri";
    private static final String KEY_LANGUAGE_PREFIX = "var.prefix.language";
    private static final String KEY_TYPE_PREFIX = "var.prefix.type";
    private static final String KEY_TYPE_VARGENERATOR = "var.generator.type";
    private static final String KEY_MAIN_STATICIZER_PATH = "staticizer.custom.folder.path";
    private static final String KEY_CUSTOM_STATICIZER_PATH = "staticizer.custom.folder";
    private static final String KEY_FORCE_HTML = "var.force.html";
    private static String uriPrefix;
    private static String languagePrefix;
    private static String typePrefix;
    private static String lineSeparator;
    private static String folderSeparator;
    private static String varGeneratorType;
    private static org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);
    private final Properties properties;

    public VarGenerator() throws Exception {
        properties = eu.europa.ec.re3gistrycommon.utils.Configuration.getInstance().getProperties(Constants.MODULE_NAME);

        /**
         * Getting properties
         */
        uriPrefix = properties.getProperty(KEY_URI_PREFIX, "URI:");
        languagePrefix = properties.getProperty(KEY_LANGUAGE_PREFIX, "Content-language:");
        typePrefix = properties.getProperty(KEY_TYPE_PREFIX, "Content-type:");
        varGeneratorType = properties.getProperty(KEY_TYPE_VARGENERATOR, "1");
        lineSeparator = System.getProperty("line.separator");
        folderSeparator = System.getProperty("file.separator");
    }

    public void writeVar(File folder) throws Exception {
        File[] fileList = folder.listFiles();
        String toVar = "";
        HashMap  htmlwritten = new HashMap();
        String forceHtml = properties.getProperty(KEY_FORCE_HTML);
        
        /**
         * For each file item in this folder
         */
        for (File file : fileList) {
            /**
             * Check if the file item is a file
             */
            if (file.isFile()) {
                /**
                 * Splitting the filename (pattern
                 * <filename>.<languagecode>.<extension>)
                 */
                String[] tmp = file.getName().split("\\.");
                
                if (tmp.length > 2 || (tmp.length == 2 && tmp[1].equals("ror"))) {

                    String type = tmp[tmp.length - 1];
                    String language;
                    
                    // Supporting the RoR formats with no language (taking english as default)
                    if(tmp.length > 2){
                        language = tmp[tmp.length - 2];
                    }else{
                        language = "en";
                    }
                    
                    //Var for the HTML json interface
                    if ((type.equals("html") && varGeneratorType.equals("2")) || (forceHtml.equals("1") && !htmlwritten.containsKey(language))) {
                        /**
                         * Creating the var string for this the dynamic HTML
                         * interface
                         */
                        String tmptype = "html";

                        String tmpMainFolder = properties.getProperty(KEY_MAIN_STATICIZER_PATH) + File.separator + properties.getProperty(KEY_CUSTOM_STATICIZER_PATH);
                        tmpMainFolder = tmpMainFolder.replace("/", File.separator);
                        tmpMainFolder = tmpMainFolder.replace("\\", File.separator);

                        String tmpCheck = folder.getAbsolutePath();
                        tmpCheck = tmpCheck.replace(tmpMainFolder, "");

                        //Replacing version folder
                        //tmpCheck = tmpCheck.replaceAll("\\\\[0-9]+$", "");
                        //tmpCheck = tmpCheck.replaceAll("/[0-9]+$", "");                    
                        tmpCheck = tmpCheck.replaceAll("\\\\_v_[0-9]+$", "");
                        tmpCheck = tmpCheck.replaceAll("/_v_[0-9]+$", "");

                        String tmpsplit[];

                        if (tmpCheck.contains("/")) {
                            tmpsplit = tmpCheck.split("/");
                        }else{
                            tmpsplit = tmpCheck.split("\\\\");
                        }

                        String tmpPrefix = "";
                        if (tmpsplit.length > 0) {
                            for (int i = 1; i < tmpsplit.length - 1; i++) {
                                tmpPrefix += "../";
                            }
                        }

                        toVar += uriPrefix + " " + tmpPrefix + "webapp/index.php" + lineSeparator;
                        toVar += languagePrefix + " " + properties.getProperty("content.language." + language) + lineSeparator;
                        toVar += typePrefix + " " + properties.getProperty("content.type." + tmptype) + lineSeparator;
                        toVar += lineSeparator;
                        
                        htmlwritten.put(language, true);
                    } 
                    
                    if(!type.equals("html") || (type.equals("html") && !htmlwritten.containsKey(language))){
                        /**
                         * Creating the var string for this file (language and
                         * extension information are taken from the properties
                         * file)
                         */
                        
                        String versionPath="";
                        if(properties.getProperty("var.generator.appendbasefolder").equals("1")){
                            String tmps[] =  file.getName().split("\\.");
                            
                            int tmpVersionPos = file.getPath().lastIndexOf(File.separator);
                            if(tmpVersionPos>=0){
                                String tmpVersion = file.getPath().substring(0, tmpVersionPos);
                                tmpVersionPos = tmpVersion.lastIndexOf(File.separator);
                                if(tmpVersionPos>=0){
                                    tmpVersion = tmpVersion.substring(tmpVersionPos+1);
                                }
                                //if(tmpVersion.matches("\\d+")){
                                if(tmpVersion.matches("_v_\\d+")){
                                    versionPath = tmpVersion + "/";
                                }else{
                                    versionPath = "";
                                }
                            }
                            
                            toVar += uriPrefix + " " + tmps[0] + "/" + versionPath + file.getName() + lineSeparator;
                        }else{
                            toVar += uriPrefix + " " + file.getName() + lineSeparator;
                        }
                        toVar += languagePrefix + " " + properties.getProperty("content.language." + language) + lineSeparator;
                        toVar += typePrefix + " " + properties.getProperty("content.type." + type) + lineSeparator;
                        toVar += lineSeparator;
                        
                        if (type.equals("html")){
                            htmlwritten.put(language, true);
                        }
                    }
                }
            }
            
            
            
            /**
             * Writing the .var file
             */
            File var = new File(folder.getAbsolutePath() + folderSeparator + "cn.var");
            FileUtils.writeStringToFile(var, toVar);
            log.info("Create with success: " + var.getAbsolutePath());
        }
    }
}
